.. _install:

Installing qp
=============

For now the only installation type that is support is installing from source.   Since `qp` is all python code, this is pretty easy.


Installing from source
-----------------------

.. code-block:: bash

    git clone https://github.com/LSSTDESC/qp.git
    cd qp
    python setup.py install

